CollideForce class

碰撞力节点 用于防止节点重叠

Inheritance

Constructors

CollideForce([ForceFun<GraphNode>? radiusFun])

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ num
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ num
getter/setter pairinherited

Methods

force([double alpha = 1]) → void
override
initialize(Context context, Graph graph, LCG lcg, num width, num height) → void
override
iterations([int? count]) → CollideForce
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onFinish() → void
inherited
radius([ForceFun<GraphNode>? fun]) → CollideForce
strength([double? v]) → CollideForce
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited