Config class

Constructors

Config({RankDir rankDir = RankDir.ttb, GraphAlign? align, num marginX = 0, num marginY = 0, num rankSep = 50, num edgeSep = 10, num nodeSep = 10, Acyclicer acyclicer = Acyclicer.none, Ranker ranker = Ranker.networkSimplex, num? width, num? height})

Properties

acyclicer → Acyclicer
控制查找图形时使用的方法
final
align → GraphAlign?
final
edgeSep → num
边之间的水平间距
final
hashCode → int
The hash code for this object.
no setterinherited
height → num?
final
marginX → num
节点水平之间的间距
final
marginY → num
节点竖直之间的间距
final
nodeSep → num
节点之间水平间距
final
rankDir → RankDir
final
ranker → Ranker
控制为图中每个节点分配层级的算法类型
final
rankSep → num
不同rank层之间的间距
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → num?
设置布局的宽度和高度
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited