GaugePoint1 class

Inheritance

Constructors

GaugePoint1({double outerRadius = 15, double innerRadius = 7, double angleSize = 20, Color innerColor = Colors.white, Color outerColor = Colors.blueAccent})

Properties

angleSize double
final
hashCode int
The hash code for this object.
no setterinherited
innerColor Color
final
innerRadius double
final
outerColor Color
final
outerRadius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

draw(Canvas canvas, Paint paint, Offset center, double radius, double angle, Offset end) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited