GaugeProgress class

Constructors

GaugeProgress({bool enable = true, bool overlap = true, bool roundCap = false, bool clip = false, Align2 align = Align2.end, required StyleFun<double, LineStyle>? styleFun, LineStyle? backgroundStyle, GaugeProgress? progress, FormatterFun<double>? formatter})

Properties

align → Align2
final
backgroundStyle → LineStyle?
final
clip bool
final
enable bool
final
formatter → FormatterFun<double>?
final
hashCode int
The hash code for this object.
no setterinherited
overlap bool
final
progress GaugeProgress?
final
roundCap bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleFun → StyleFun<double, LineStyle>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited