TreemapLayout class abstract

Implementers

Constructors

TreemapLayout(TreeMapSeries series)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
series → TreeMapSeries
final

Methods

layout(TreeMapNode root, Rect area) → void
给定一个区域范围和节点,对该节点的Children进行布局(不包含孩子的孩子)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited