XForce class

Inheritance

Constructors

XForce([ForceFun? xFun])

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ num
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ num
getter/setter pairinherited

Methods

force([double alpha = 1]) → void
override
initialize(Context context, Graph graph, LCG lcg, num width, num height) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onFinish() → void
inherited
strength([ForceFun? fun]) → XForce
toString() → String
A string representation of this object.
inherited
x([ForceFun? fun]) → XForce

Operators

operator ==(Object other) → bool
The equality operator.
inherited