DagreEdge<T> class
Constructors
Properties
- data → T?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → num
-
final
- id → String
-
final
- labelOffset → num
-
final
- labelPos → LabelPosition
-
final
- minLen → num
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → DagreNode
-
final
- target → DagreNode
-
final
- weight → num
-
final
- width → num
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override